@@ -6,6 +6,7 @@ cols <- c("team_id", "team", "mascot", "nickname", "abbreviation",
 test_that("ESPN - WBB Teams", {
   skip_on_cran()
   x <- espn_wbb_teams()
-  expect_equal(colnames(x), cols)
+  
+  expect_equal(sort(colnames(x)), sort(cols))
   expect_s3_class(x, "data.frame")
-})
\ No newline at end of file
+})
